// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtpdf_python.h"

// main header
#include "qpdflinkmodel_wrapper.h"

// Wrappers providing overrides
#include "qpdfpagerenderer_wrapper.h"
#include "qpdfbookmarkmodel_wrapper.h"

// Argument includes
#include <QHash>
#include <QList>
#include <QMap>
#include <QStringList>
#include <QtPdf/qpdfdocument.h>
#include <QtPdf/qpdflink.h>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qmimedata.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QPdfLinkModelWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPdfLinkModelWrapper::QPdfLinkModelWrapper(::QObject * parent) : QPdfLinkModel(parent)
{
}

::QModelIndex QPdfLinkModelWrapper::buddy(const ::QModelIndex & index) const
{
    static const char *funcName = "buddy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::buddy(index);
    }
    return QPdfBookmarkModelWrapper::sbk_o_buddy("QPdfLinkModel", funcName, gil, pyOverride, index);
}

bool QPdfLinkModelWrapper::canDropMimeData(const ::QMimeData * data, ::Qt::DropAction action, int row, int column, const ::QModelIndex & parent) const
{
    static const char *funcName = "canDropMimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::canDropMimeData(data, action, row, column, parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_canDropMimeData("QPdfLinkModel", funcName, gil, pyOverride, data, action, row, column, parent);
}

bool QPdfLinkModelWrapper::canFetchMore(const ::QModelIndex & parent) const
{
    static const char *funcName = "canFetchMore";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::canFetchMore(parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_canFetchMore("QPdfLinkModel", funcName, gil, pyOverride, parent);
}

void QPdfLinkModelWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QPdfPageRendererWrapper::sbk_o_childEvent("QPdfLinkModel", funcName, gil, pyOverride, event);
}

bool QPdfLinkModelWrapper::clearItemData(const ::QModelIndex & index)
{
    static const char *funcName = "clearItemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::clearItemData(index);
    }
    return QPdfBookmarkModelWrapper::sbk_o_canFetchMore("QPdfLinkModel", funcName, gil, pyOverride, index);
}

void QPdfLinkModelWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QPdfPageRendererWrapper::sbk_o_connectNotify("QPdfLinkModel", funcName, gil, pyOverride, signal);
}

void QPdfLinkModelWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QPdfPageRendererWrapper::sbk_o_customEvent("QPdfLinkModel", funcName, gil, pyOverride, event);
}

::QVariant QPdfLinkModelWrapper::data(const ::QModelIndex & index, int role) const
{
    static const char *funcName = "data";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPdfLinkModel::data(index, role);
    }
    return QPdfBookmarkModelWrapper::sbk_o_data("QPdfLinkModel", funcName, gil, pyOverride, index, role);
}

void QPdfLinkModelWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QPdfPageRendererWrapper::sbk_o_connectNotify("QPdfLinkModel", funcName, gil, pyOverride, signal);
}

bool QPdfLinkModelWrapper::dropMimeData(const ::QMimeData * data, ::Qt::DropAction action, int row, int column, const ::QModelIndex & parent)
{
    static const char *funcName = "dropMimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractListModel::dropMimeData(data, action, row, column, parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_canDropMimeData("QPdfLinkModel", funcName, gil, pyOverride, data, action, row, column, parent);
}

bool QPdfLinkModelWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QPdfPageRendererWrapper::sbk_o_event("QPdfLinkModel", funcName, gil, pyOverride, event);
}

bool QPdfLinkModelWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QPdfPageRendererWrapper::sbk_o_eventFilter("QPdfLinkModel", funcName, gil, pyOverride, watched, event);
}

void QPdfLinkModelWrapper::fetchMore(const ::QModelIndex & parent)
{
    static const char *funcName = "fetchMore";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::fetchMore(parent);
    }
    QPdfBookmarkModelWrapper::sbk_o_fetchMore("QPdfLinkModel", funcName, gil, pyOverride, parent);
}

::QFlags<Qt::ItemFlag> QPdfLinkModelWrapper::flags(const ::QModelIndex & index) const
{
    static const char *funcName = "flags";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractListModel::flags(index);
    }
    return QPdfBookmarkModelWrapper::sbk_o_flags("QPdfLinkModel", funcName, gil, pyOverride, index);
}

::QVariant QPdfLinkModelWrapper::headerData(int section, ::Qt::Orientation orientation, int role) const
{
    static const char *funcName = "headerData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::headerData(section, orientation, role);
    }
    return QPdfBookmarkModelWrapper::sbk_o_headerData("QPdfLinkModel", funcName, gil, pyOverride, section, orientation, role);
}

::QModelIndex QPdfLinkModelWrapper::index(int row, int column, const ::QModelIndex & parent) const
{
    static const char *funcName = "index";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractListModel::index(row, column, parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_index("QPdfLinkModel", funcName, gil, pyOverride, row, column, parent);
}

bool QPdfLinkModelWrapper::insertColumns(int column, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "insertColumns";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::insertColumns(column, count, parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_insertColumns("QPdfLinkModel", funcName, gil, pyOverride, column, count, parent);
}

bool QPdfLinkModelWrapper::insertRows(int row, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "insertRows";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::insertRows(row, count, parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_insertColumns("QPdfLinkModel", funcName, gil, pyOverride, row, count, parent);
}

::QMap<int,QVariant> QPdfLinkModelWrapper::itemData(const ::QModelIndex & index) const
{
    static const char *funcName = "itemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::itemData(index);
    }
    return QPdfBookmarkModelWrapper::sbk_o_itemData("QPdfLinkModel", funcName, gil, pyOverride, index);
}

::QList<QModelIndex> QPdfLinkModelWrapper::match(const ::QModelIndex & start, int role, const ::QVariant & value, int hits, ::QFlags<Qt::MatchFlag> flags) const
{
    static const char *funcName = "match";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::match(start, role, value, hits, flags);
    }
    return QPdfBookmarkModelWrapper::sbk_o_match("QPdfLinkModel", funcName, gil, pyOverride, start, role, value, hits, flags);
}

::QMimeData * QPdfLinkModelWrapper::mimeData(const ::QList<QModelIndex> & indexes) const
{
    static const char *funcName = "mimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::mimeData(indexes);
    }
    return QPdfBookmarkModelWrapper::sbk_o_mimeData("QPdfLinkModel", funcName, gil, pyOverride, indexes);
}

::QStringList QPdfLinkModelWrapper::mimeTypes() const
{
    static const char *funcName = "mimeTypes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::mimeTypes();
    }
    return QPdfBookmarkModelWrapper::sbk_o_mimeTypes("QPdfLinkModel", funcName, gil, pyOverride);
}

bool QPdfLinkModelWrapper::moveColumns(const ::QModelIndex & sourceParent, int sourceColumn, int count, const ::QModelIndex & destinationParent, int destinationChild)
{
    static const char *funcName = "moveColumns";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::moveColumns(sourceParent, sourceColumn, count, destinationParent, destinationChild);
    }
    return QPdfBookmarkModelWrapper::sbk_o_moveColumns("QPdfLinkModel", funcName, gil, pyOverride, sourceParent, sourceColumn, count, destinationParent, destinationChild);
}

bool QPdfLinkModelWrapper::moveRows(const ::QModelIndex & sourceParent, int sourceRow, int count, const ::QModelIndex & destinationParent, int destinationChild)
{
    static const char *funcName = "moveRows";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::moveRows(sourceParent, sourceRow, count, destinationParent, destinationChild);
    }
    return QPdfBookmarkModelWrapper::sbk_o_moveColumns("QPdfLinkModel", funcName, gil, pyOverride, sourceParent, sourceRow, count, destinationParent, destinationChild);
}

void QPdfLinkModelWrapper::multiData(const ::QModelIndex & index, ::QModelRoleDataSpan roleDataSpan) const
{
    static const char *funcName = "multiData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::multiData(index, roleDataSpan);
    }
    QPdfBookmarkModelWrapper::sbk_o_multiData("QPdfLinkModel", funcName, gil, pyOverride, index, roleDataSpan);
}

bool QPdfLinkModelWrapper::removeColumns(int column, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "removeColumns";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::removeColumns(column, count, parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_insertColumns("QPdfLinkModel", funcName, gil, pyOverride, column, count, parent);
}

bool QPdfLinkModelWrapper::removeRows(int row, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "removeRows";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::removeRows(row, count, parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_insertColumns("QPdfLinkModel", funcName, gil, pyOverride, row, count, parent);
}

void QPdfLinkModelWrapper::resetInternalData()
{
    static const char *funcName = "resetInternalData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::resetInternalData();
    }
    QPdfBookmarkModelWrapper::sbk_o_resetInternalData("QPdfLinkModel", funcName, gil, pyOverride);
}

void QPdfLinkModelWrapper::revert()
{
    static const char *funcName = "revert";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::revert();
    }
    QPdfBookmarkModelWrapper::sbk_o_resetInternalData("QPdfLinkModel", funcName, gil, pyOverride);
}

::QHash<int,QByteArray> QPdfLinkModelWrapper::roleNames() const
{
    static const char *funcName = "roleNames";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPdfLinkModel::roleNames();
    }
    return QPdfBookmarkModelWrapper::sbk_o_roleNames("QPdfLinkModel", funcName, gil, pyOverride);
}

int QPdfLinkModelWrapper::rowCount(const ::QModelIndex & parent) const
{
    static const char *funcName = "rowCount";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPdfLinkModel::rowCount(parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_columnCount("QPdfLinkModel", funcName, gil, pyOverride, parent);
}

bool QPdfLinkModelWrapper::setData(const ::QModelIndex & index, const ::QVariant & value, int role)
{
    static const char *funcName = "setData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::setData(index, value, role);
    }
    return QPdfBookmarkModelWrapper::sbk_o_setData("QPdfLinkModel", funcName, gil, pyOverride, index, value, role);
}

bool QPdfLinkModelWrapper::setHeaderData(int section, ::Qt::Orientation orientation, const ::QVariant & value, int role)
{
    static const char *funcName = "setHeaderData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::setHeaderData(section, orientation, value, role);
    }
    return QPdfBookmarkModelWrapper::sbk_o_setHeaderData("QPdfLinkModel", funcName, gil, pyOverride, section, orientation, value, role);
}

bool QPdfLinkModelWrapper::setItemData(const ::QModelIndex & index, const ::QMap<int,QVariant> & roles)
{
    static const char *funcName = "setItemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::setItemData(index, roles);
    }
    return QPdfBookmarkModelWrapper::sbk_o_setItemData("QPdfLinkModel", funcName, gil, pyOverride, index, roles);
}

::QModelIndex QPdfLinkModelWrapper::sibling(int row, int column, const ::QModelIndex & idx) const
{
    static const char *funcName = "sibling";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractListModel::sibling(row, column, idx);
    }
    return QPdfBookmarkModelWrapper::sbk_o_index("QPdfLinkModel", funcName, gil, pyOverride, row, column, idx);
}

void QPdfLinkModelWrapper::sort(int column, ::Qt::SortOrder order)
{
    static const char *funcName = "sort";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::sort(column, order);
    }
    QPdfBookmarkModelWrapper::sbk_o_sort("QPdfLinkModel", funcName, gil, pyOverride, column, order);
}

::QSize QPdfLinkModelWrapper::span(const ::QModelIndex & index) const
{
    static const char *funcName = "span";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::span(index);
    }
    return QPdfBookmarkModelWrapper::sbk_o_span("QPdfLinkModel", funcName, gil, pyOverride, index);
}

bool QPdfLinkModelWrapper::submit()
{
    static const char *funcName = "submit";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::submit();
    }
    return QPdfBookmarkModelWrapper::sbk_o_submit("QPdfLinkModel", funcName, gil, pyOverride);
}

::QFlags<Qt::DropAction> QPdfLinkModelWrapper::supportedDragActions() const
{
    static const char *funcName = "supportedDragActions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::supportedDragActions();
    }
    return QPdfBookmarkModelWrapper::sbk_o_supportedDragActions("QPdfLinkModel", funcName, gil, pyOverride);
}

::QFlags<Qt::DropAction> QPdfLinkModelWrapper::supportedDropActions() const
{
    static const char *funcName = "supportedDropActions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::supportedDropActions();
    }
    return QPdfBookmarkModelWrapper::sbk_o_supportedDragActions("QPdfLinkModel", funcName, gil, pyOverride);
}

void QPdfLinkModelWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QPdfPageRendererWrapper::sbk_o_timerEvent("QPdfLinkModel", funcName, gil, pyOverride, event);
}

const QMetaObject *QPdfLinkModelWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QPdfLinkModel::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QPdfLinkModelWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QPdfLinkModel::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QPdfLinkModelWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QPdfLinkModelWrapper *>(this));
    return QPdfLinkModel::qt_metacast(_clname);
}

QPdfLinkModelWrapper::~QPdfLinkModelWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPdfLinkModel_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPdfLinkModel >()))
        return -1;

    QPdfLinkModelWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QPdfLinkModel", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPdfLinkModel::QPdfLinkModel(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QPdfLinkModel(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QPdfLinkModel(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QPdfLinkModel(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QPdfLinkModelWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QPdfLinkModelWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QPdfLinkModel >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QPdfLinkModelFunc_data(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLinkModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "data", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::data(QModelIndex,int)const->QVariant
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // data(QModelIndex,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // data(QModelIndex,int)const
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QPdfLinkModel *>(cppSelf)->::QPdfLinkModel::data(*cppArg0, cppArg1)
                : const_cast<const ::QPdfLinkModel *>(cppSelf)->data(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfLinkModelFunc_document(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLinkModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // document()const
        QPdfDocument * cppResult = const_cast<const ::QPdfLinkModel *>(cppSelf)->document();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfLinkModelFunc_linkAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLinkModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfLinkModel::linkAt(QPointF)const->QPdfLink
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 0; // linkAt(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "linkAt", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPointF cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // linkAt(QPointF)const
            QPdfLink cppResult = const_cast<const ::QPdfLinkModel *>(cppSelf)->linkAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfLinkModelFunc_page(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLinkModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // page()const
        int cppResult = const_cast<const ::QPdfLinkModel *>(cppSelf)->page();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfLinkModelFunc_roleNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLinkModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // roleNames()const
        QHash<int,QByteArray> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QPdfLinkModel *>(cppSelf)->::QPdfLinkModel::roleNames()
            : const_cast<const ::QPdfLinkModel *>(cppSelf)->roleNames();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPdfTypeConverters[SBK_QtPdf_QHash_int_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfLinkModelFunc_rowCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLinkModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemModel::rowCount(QModelIndex)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // rowCount(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "rowCount", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // rowCount(QModelIndex)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QPdfLinkModel *>(cppSelf)->::QPdfLinkModel::rowCount(*cppArg0)
                : const_cast<const ::QPdfLinkModel *>(cppSelf)->rowCount(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfLinkModelFunc_setDocument(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLinkModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfLinkModel::setDocument(QPdfDocument*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), (pyArg)))) {
        overloadId = 0; // setDocument(QPdfDocument*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDocument", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPdfDocument *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDocument(QPdfDocument*)
            cppSelf->setDocument(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPdfLinkModelFunc_setPage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLinkModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfLinkModel::setPage(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setPage(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPage", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPage(int)
            cppSelf->setPage(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QPdfLinkModel_PropertyStrings[] = {
    "document::",
    "page::",
    nullptr // Sentinel
};

static const char *Sbk_QPdfLinkModel_EnumFlagInfo[] = {
    "Role:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPdfLinkModel_methods[] = {
    {"data", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkModelFunc_data), METH_VARARGS, nullptr},
    {"document", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkModelFunc_document), METH_NOARGS, nullptr},
    {"linkAt", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkModelFunc_linkAt), METH_O, nullptr},
    {"page", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkModelFunc_page), METH_NOARGS, nullptr},
    {"roleNames", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkModelFunc_roleNames), METH_NOARGS, nullptr},
    {"rowCount", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkModelFunc_rowCount), METH_O, nullptr},
    {"setDocument", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkModelFunc_setDocument), METH_O, nullptr},
    {"setPage", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkModelFunc_setPage), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPdfLinkModel_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QPdfLinkModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPdfLinkModelWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QPdfLinkModel_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPdfLinkModel_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPdfLinkModel_Type = nullptr;
static PyTypeObject *Sbk_QPdfLinkModel_TypeF(void)
{
    return _Sbk_QPdfLinkModel_Type;
}

static PyType_Slot Sbk_QPdfLinkModel_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPdfLinkModel_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPdfLinkModel_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPdfLinkModel_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPdfLinkModel_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPdfLinkModel_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPdfLinkModel_spec = {
    "2:PySide6.QtPdf.QPdfLinkModel",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPdfLinkModel_slots
};

} //extern "C"

static void *Sbk_QPdfLinkModel_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QPdfLinkModel *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QPdfLinkModel_Role(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPdfLinkModel::Role>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPdfLinkModel::Role *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPdfLinkModel_Role_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_Role_IDX])))
        return Enum_PythonToCpp_QPdfLinkModel_Role;
    return {};
}

static PyObject *QPdfLinkModel_Role_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPdfLinkModel::Role>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPdfLinkModel::Role *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_Role_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPdfLinkModel_PythonToCpp_QPdfLinkModel_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPdfLinkModel_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPdfLinkModel_PythonToCpp_QPdfLinkModel_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPdfLinkModel_TypeF()))
        return QPdfLinkModel_PythonToCpp_QPdfLinkModel_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPdfLinkModel_PTR_CppToPython_QPdfLinkModel(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QPdfLinkModel *>(const_cast<void *>(cppIn)), Sbk_QPdfLinkModel_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPdfLinkModel_SignatureStrings[] = {
    "PySide6.QtPdf.QPdfLinkModel(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,document:QPdfDocument=None,page:int=None)",
    "PySide6.QtPdf.QPdfLinkModel.data(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],role:int)->QVariant",
    "PySide6.QtPdf.QPdfLinkModel.document(self)->PySide6.QtPdf.QPdfDocument",
    "PySide6.QtPdf.QPdfLinkModel.linkAt(self,point:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])->PySide6.QtPdf.QPdfLink",
    "PySide6.QtPdf.QPdfLinkModel.page(self)->int",
    "PySide6.QtPdf.QPdfLinkModel.roleNames(self)->QHash[int, PySide6.QtCore.QByteArray]",
    "PySide6.QtPdf.QPdfLinkModel.rowCount(self,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->int",
    "PySide6.QtPdf.QPdfLinkModel.setDocument(self,document:PySide6.QtPdf.QPdfDocument)",
    "PySide6.QtPdf.QPdfLinkModel.setPage(self,page:int)",
    nullptr}; // Sentinel
#else
static constexpr size_t QPdfLinkModel_SignatureByteSize = 306;
static constexpr uint8_t QPdfLinkModel_SignatureBytes[306] = {
    0x78, 0xda, 0xad, 0x93, 0x4d, 0x4f, 0xc3, 0x30, 0x0c, 0x86, 0xef, 0xfb, 0x15, 0x1c, 0x29, 0x2a,
    0x39, 0x72, 0xa8, 0x34, 0xa4, 0xb1, 0xf1, 0x25, 0x60, 0x4b, 0x85, 0xe0, 0x32, 0xf5, 0x10, 0x16,
    0x6f, 0x0b, 0x64, 0x49, 0x95, 0xb8, 0x1a, 0xf9, 0xf7, 0x24, 0x5d, 0xbb, 0x8f, 0xb2, 0xb5, 0x1c,
    0xb8, 0x54, 0x8d, 0xf3, 0xda, 0x7d, 0x5e, 0xdb, 0xa5, 0xee, 0x55, 0x70, 0xb8, 0x22, 0x29, 0x52,
    0x3e, 0x27, 0xa9, 0x7f, 0x3c, 0x0b, 0xf5, 0xf5, 0xa2, 0x39, 0xc8, 0x73, 0x0b, 0x72, 0x1e, 0xe7,
    0xcc, 0x80, 0xc2, 0x84, 0x6e, 0x75, 0x43, 0x6d, 0x80, 0xa4, 0x93, 0x8f, 0x4f, 0x98, 0x61, 0x5f,
    0x15, 0x52, 0xe6, 0x68, 0xe2, 0x8b, 0xe4, 0x09, 0xdc, 0x5a, 0x1b, 0x3e, 0x51, 0xd2, 0xf5, 0xc7,
    0x5a, 0x41, 0xcc, 0xf5, 0xac, 0x58, 0x85, 0xd4, 0x50, 0x74, 0x54, 0x1d, 0x36, 0x57, 0x39, 0x5b,
    0x40, 0x22, 0xaa, 0x53, 0xd4, 0xa3, 0xa7, 0x19, 0x08, 0x67, 0xc8, 0x36, 0x20, 0x42, 0x71, 0xf8,
    0x4e, 0xd0, 0xe5, 0x42, 0x2d, 0xc8, 0x9b, 0x12, 0x5a, 0x4d, 0x9b, 0x50, 0x65, 0xca, 0x63, 0xd0,
    0xc5, 0x67, 0xcd, 0x3b, 0x0a, 0xc6, 0x0a, 0x8b, 0x9e, 0x61, 0xa7, 0xca, 0x62, 0xa3, 0x65, 0x49,
    0x12, 0x5d, 0x5e, 0xa7, 0xef, 0xcc, 0x08, 0xa6, 0xb0, 0x1d, 0xa7, 0xf2, 0x51, 0x22, 0xf9, 0xa4,
    0xdf, 0xda, 0xda, 0x69, 0x6b, 0x19, 0xe9, 0xdf, 0x06, 0x58, 0x35, 0x58, 0xfb, 0xef, 0xb7, 0xfb,
    0xa2, 0x41, 0x72, 0x77, 0xc4, 0x53, 0x88, 0xef, 0x87, 0xef, 0x0b, 0xe1, 0xa3, 0xcc, 0x47, 0xc1,
    0x50, 0x86, 0x4b, 0x72, 0x2b, 0x21, 0xc0, 0x64, 0x47, 0x51, 0x03, 0x4f, 0x2b, 0x66, 0x98, 0x53,
    0xed, 0x54, 0x74, 0x58, 0x0a, 0x9d, 0x1c, 0xb3, 0x15, 0xd8, 0x3a, 0x21, 0x7d, 0x60, 0x76, 0x39,
    0x6d, 0x00, 0x6e, 0xb8, 0x6f, 0x1c, 0xc2, 0xc0, 0x18, 0xe6, 0xb2, 0x8e, 0x92, 0xeb, 0xa1, 0x2e,
    0x14, 0x1e, 0x2c, 0xe2, 0xff, 0x2e, 0xc0, 0x1f, 0x8c, 0x59, 0xc0, 0xd1, 0xfe, 0xd4, 0x77, 0x8b,
    0x7d, 0x7a, 0xf8, 0x51, 0x57, 0x45, 0x5a, 0x77, 0x76, 0xfb, 0x2f, 0x44, 0xbd, 0x1f, 0xf4, 0x9f,
    0x44, 0x4e
};
#endif

PyTypeObject *init_QPdfLinkModel(PyObject *module)
{
    if (SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX].type != nullptr)
        return SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX].type;

    Shiboken::AutoDecRef Sbk_QPdfLinkModel_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractListModel_IDX]))));

    _Sbk_QPdfLinkModel_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPdfLinkModel",
        "QPdfLinkModel*",
        &Sbk_QPdfLinkModel_spec,
        &Shiboken::callCppDestructor< QPdfLinkModel >,
        Sbk_QPdfLinkModel_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPdfLinkModel_TypeF(); // references _Sbk_QPdfLinkModel_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPdfLinkModel_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPdfLinkModel_SignatureBytes, QPdfLinkModel_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPdfLinkModel_PropertyStrings);
    SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPdfLinkModel_PythonToCpp_QPdfLinkModel_PTR,
        is_QPdfLinkModel_PythonToCpp_QPdfLinkModel_PTR_Convertible,
        QPdfLinkModel_PTR_CppToPython_QPdfLinkModel);

    Shiboken::Conversions::registerConverterName(converter, "QPdfLinkModel");
    Shiboken::Conversions::registerConverterName(converter, "QPdfLinkModel*");
    Shiboken::Conversions::registerConverterName(converter, "QPdfLinkModel&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPdfLinkModel).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPdfLinkModelWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QPdfLinkModel_TypeF(), &Sbk_QPdfLinkModel_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QPdfLinkModel_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Role'.
    const char *Role_Initializer[] = {
        "Link",
        "Rectangle",
        "Url",
        "Page",
        "Location",
        "Zoom",
        "NRoles",
        nullptr};
    // "int16_t" used instead of "int"
    constexpr int16_t Role_InitializerValues[] = {
        int16_t(QPdfLinkModel::Role::Link),      //  0x0100  256
        int16_t(QPdfLinkModel::Role::Rectangle), //  0x0101  257
        int16_t(QPdfLinkModel::Role::Url),       //  0x0102  258
        int16_t(QPdfLinkModel::Role::Page),      //  0x0103  259
        int16_t(QPdfLinkModel::Role::Location),  //  0x0104  260
        int16_t(QPdfLinkModel::Role::Zoom),      //  0x0105  261
        int16_t(QPdfLinkModel::Role::NRoles)     //  0x0106  262
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPdfLinkModel_TypeF(),
        "2:PySide6.QtPdf.QPdfLinkModel.Role",
        Role_Initializer, Role_InitializerValues);
    SbkPySide6_QtPdfTypeStructs[SBK_QPdfLinkModel_Role_IDX].type = EType;
    // Register converter for enum 'QPdfLinkModel::Role'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPdfLinkModel_Role_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPdfLinkModel_Role,
            is_Enum_PythonToCpp_QPdfLinkModel_Role_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPdfLinkModel::Role");
        Shiboken::Conversions::registerConverterAlias(converter, "Role");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Role' enum.

    PySide::Signal::registerSignals(pyType, &::QPdfLinkModel::staticMetaObject);
    qRegisterMetaType< ::QPdfLinkModel::Role >("QPdfLinkModel::Role");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QPdfLinkModel::staticMetaObject, sizeof(QPdfLinkModelWrapper));

    return pyType;
}
