// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebengineframe_wrapper.h"

// Extra includes
#include <glue/webengineframe.h>
#include <glue/webenginepage_functors.h>

// Argument includes
#include <QList>
#include <QString>
#include <QtWebEngineCore/qwebengineframe.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsize.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEngineFrame_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEngineFrame >()))
        return -1;

    ::QWebEngineFrame *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QWebEngineFrame", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWebEngineFrame::QWebEngineFrame(QWebEngineFrame)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QWebEngineFrame(QWebEngineFrame)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWebEngineFrame cppArg0_local = defaultConstructedWebEngineFrame();
        ::QWebEngineFrame *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // QWebEngineFrame(QWebEngineFrame)
            cptr = new ::QWebEngineFrame(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWebEngineFrame >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QWebEngineFrameFunc_children(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // children()const
        QList<QWebEngineFrame> cppResult = const_cast<const ::QWebEngineFrame *>(cppSelf)->children();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWebEngineCoreTypeConverters[SBK_QtWebEngineCore_QList_QWebEngineFrame_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineFrameFunc_htmlName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // htmlName()const
        QString cppResult = const_cast<const ::QWebEngineFrame *>(cppSelf)->htmlName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineFrameFunc_isMainFrame(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isMainFrame()const
        bool cppResult = const_cast<const ::QWebEngineFrame *>(cppSelf)->isMainFrame();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineFrameFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QWebEngineFrame *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineFrameFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QWebEngineFrame *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineFrameFunc_printToPdf(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineFrame::printToPdf(PyCallable*)
    // 1: QWebEngineFrame::printToPdf(QString)
    if (PyCallable_Check(pyArg)) {
        overloadId = 0; // printToPdf(PyCallable*)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // printToPdf(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "printToPdf", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // printToPdf(PyCallable *resultCallback)
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // printToPdf(PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtwebenginecore.cpp (qwebengineframe-printtopdf)]
                using PrintToPdfCallback = std::function<void(const QByteArray &)>;

                cppSelf->printToPdf(PrintToPdfCallback(PrintToPdfFunctor(pyArg)));
                // END of custom code block [file: ../glue/qtwebenginecore.cpp (qwebengineframe-printtopdf)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // printToPdf(const QString &filePath)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // printToPdf(QString)
                cppSelf->printToPdf(cppArg0);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWebEngineFrameFunc_runJavaScript(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "runJavaScript", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:runJavaScript", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEngineFrame::runJavaScript(QString,PyCallable*)
    // 1: QWebEngineFrame::runJavaScript(QString,quint32,PyCallable*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // runJavaScript(QString,quint32,PyCallable*)
            } else if (numArgs >= 3
                && PyCallable_Check(pyArgs[2])) {
                overloadId = 1; // runJavaScript(QString,quint32,PyCallable*)
            }
        } else if (numArgs == 2
            && PyCallable_Check(pyArgs[1])) {
            overloadId = 0; // runJavaScript(QString,PyCallable*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "runJavaScript", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // runJavaScript(const QString &scriptSource, PyCallable *resultCallback)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "runJavaScript", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // runJavaScript(QString,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtwebenginecore.cpp (qwebenginepage-runjavascript-2)]
                using RunJavascriptCallback = std::function<void(const QVariant &)>;

                if (pyArgs[2-1] != nullptr && pyArgs[2-1] != Py_None) {
                    cppSelf->runJavaScript(cppArg0, RunJavascriptCallback(RunJavascriptFunctor(pyArgs[2-1])));
                } else {
                    cppSelf->runJavaScript(cppArg0, 0, RunJavascriptCallback{});
                }
                // END of custom code block [file: ../glue/qtwebenginecore.cpp (qwebenginepage-runjavascript-2)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // runJavaScript(const QString &scriptSource, quint32 worldId, PyCallable *resultCallback)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"resultCallback", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !PyCallable_Check(pyArgs[2]))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "runJavaScript", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            quint32 cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // runJavaScript(QString,quint32,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtwebenginecore.cpp (qwebenginepage-runjavascript-3)]
                using RunJavascriptCallback = std::function<void(const QVariant &)>;

                if (pyArgs[3-1] != nullptr && pyArgs[3-1] != Py_None) {
                    cppSelf->runJavaScript(cppArg0, cppArg1, RunJavascriptCallback(RunJavascriptFunctor(pyArgs[3-1])));
                } else {
                    cppSelf->runJavaScript(cppArg0, cppArg1, RunJavascriptCallback{});
                }
                // END of custom code block [file: ../glue/qtwebenginecore.cpp (qwebenginepage-runjavascript-3)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWebEngineFrameFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        QSizeF cppResult = const_cast<const ::QWebEngineFrame *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineFrameFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // url()const
        QUrl cppResult = const_cast<const ::QWebEngineFrame *>(cppSelf)->url();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineFrame__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QWebEngineFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEngineFrame_PropertyStrings[] = {
    "htmlName:",
    "isMainFrame:",
    "isValid:",
    "name:",
    "size:",
    "url:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineFrame_methods[] = {
    {"children", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFrameFunc_children), METH_NOARGS, nullptr},
    {"htmlName", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFrameFunc_htmlName), METH_NOARGS, nullptr},
    {"isMainFrame", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFrameFunc_isMainFrame), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFrameFunc_isValid), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFrameFunc_name), METH_NOARGS, nullptr},
    {"printToPdf", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFrameFunc_printToPdf), METH_O, nullptr},
    {"runJavaScript", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFrameFunc_runJavaScript), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFrameFunc_size), METH_NOARGS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFrameFunc_url), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFrame__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QWebEngineFrame_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QWebEngineFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]), (pyArg)))) {
                // operator!=(const QWebEngineFrame &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QWebEngineFrame cppArg0_local = defaultConstructedWebEngineFrame();
                ::QWebEngineFrame *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]), (pyArg)))) {
                // operator==(const QWebEngineFrame &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QWebEngineFrame cppArg0_local = defaultConstructedWebEngineFrame();
                ::QWebEngineFrame *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QWebEngineFrame_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineFrame_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineFrame_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineFrame_TypeF(void)
{
    return _Sbk_QWebEngineFrame_Type;
}

static PyType_Slot Sbk_QWebEngineFrame_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineFrame_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineFrame_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QWebEngineFrame_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineFrame_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEngineFrame_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineFrame_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineFrame",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineFrame_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineFrame_PythonToCpp_QWebEngineFrame_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineFrame_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineFrame_PythonToCpp_QWebEngineFrame_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineFrame_TypeF()))
        return QWebEngineFrame_PythonToCpp_QWebEngineFrame_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineFrame_PTR_CppToPython_QWebEngineFrame(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QWebEngineFrame_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QWebEngineFrame_COPY_CppToPython_QWebEngineFrame(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QWebEngineFrame *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QWebEngineFrame_TypeF(), new ::QWebEngineFrame(*source), true, true);
}

// Python to C++ copy conversion.
static void QWebEngineFrame_PythonToCpp_QWebEngineFrame_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QWebEngineFrame *>(cppOut) = *reinterpret_cast< ::QWebEngineFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QWebEngineFrame_PythonToCpp_QWebEngineFrame_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineFrame_TypeF()))
        return QWebEngineFrame_PythonToCpp_QWebEngineFrame_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineFrame_SignatureStrings[] = {
    "PySide6.QtWebEngineCore.QWebEngineFrame(self,QWebEngineFrame:PySide6.QtWebEngineCore.QWebEngineFrame,*:KeywordOnly=None,isValid:bool=None,name:QString=None,htmlName:QString=None,url:QUrl=None,size:QSizeF=None,isMainFrame:bool=None)",
    "PySide6.QtWebEngineCore.QWebEngineFrame.children(self)->QList[PySide6.QtWebEngineCore.QWebEngineFrame]",
    "PySide6.QtWebEngineCore.QWebEngineFrame.htmlName(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineFrame.isMainFrame(self)->bool",
    "PySide6.QtWebEngineCore.QWebEngineFrame.isValid(self)->bool",
    "PySide6.QtWebEngineCore.QWebEngineFrame.name(self)->QString",
    "1:PySide6.QtWebEngineCore.QWebEngineFrame.printToPdf(self,resultCallback:PyCallable)",
    "0:PySide6.QtWebEngineCore.QWebEngineFrame.printToPdf(self,filePath:QString)",
    "1:PySide6.QtWebEngineCore.QWebEngineFrame.runJavaScript(self,scriptSource:QString,resultCallback:PyCallable)",
    "0:PySide6.QtWebEngineCore.QWebEngineFrame.runJavaScript(self,scriptSource:QString,worldId:quint32,resultCallback:PyCallable={})",
    "PySide6.QtWebEngineCore.QWebEngineFrame.size(self)->PySide6.QtCore.QSizeF",
    "PySide6.QtWebEngineCore.QWebEngineFrame.url(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEngineFrame.__copy__(self)->typing.Self",
    "PySide6.QtWebEngineCore.QWebEngineFrame.__ne__(self,rhs:PySide6.QtWebEngineCore.QWebEngineFrame)->bool",
    "PySide6.QtWebEngineCore.QWebEngineFrame.__eq__(self,rhs:PySide6.QtWebEngineCore.QWebEngineFrame)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineFrame_SignatureByteSize = 340;
static constexpr uint8_t QWebEngineFrame_SignatureBytes[340] = {
    0x78, 0xda, 0xad, 0x93, 0x4d, 0x4f, 0x84, 0x30, 0x10, 0x86, 0xef, 0xfe, 0x12, 0xd7, 0x20, 0xf1,
    0x23, 0xf1, 0x40, 0xb2, 0x5e, 0x36, 0x6e, 0xe2, 0xd7, 0x0a, 0x41, 0xdd, 0x83, 0x31, 0xa4, 0xd0,
    0x61, 0x69, 0x9c, 0x6d, 0xd9, 0xb6, 0x68, 0xd0, 0xf8, 0xdf, 0x2d, 0x74, 0x41, 0xa3, 0x6e, 0x52,
    0x56, 0x2f, 0xa4, 0x9d, 0xf6, 0x7d, 0x66, 0x5e, 0x3a, 0x13, 0xd6, 0x31, 0xa3, 0x70, 0xe2, 0x47,
    0x7a, 0x0e, 0xe9, 0x19, 0x5f, 0x30, 0x0e, 0x13, 0x21, 0xc1, 0x8f, 0xfa, 0xed, 0x54, 0x92, 0x25,
    0xec, 0x2a, 0xc0, 0xdc, 0xfb, 0x16, 0x0c, 0x42, 0x37, 0xb1, 0xb7, 0x17, 0x5c, 0x42, 0xfd, 0x22,
    0x24, 0xbd, 0xe1, 0x58, 0x8f, 0x67, 0x82, 0x83, 0xc7, 0xd4, 0x3d, 0x41, 0x46, 0x83, 0x54, 0x08,
    0xb4, 0x11, 0xde, 0x10, 0xa3, 0x58, 0x4b, 0xc6, 0x17, 0x36, 0x52, 0xe8, 0x25, 0xce, 0x7e, 0x44,
    0x2b, 0x89, 0x41, 0x74, 0x27, 0xd7, 0x2a, 0xc5, 0x5e, 0x9b, 0x73, 0xf3, 0x9d, 0x76, 0xe0, 0x6b,
    0xc2, 0xb8, 0xad, 0xaf, 0x87, 0x8f, 0x76, 0x1c, 0x4b, 0xf5, 0xb3, 0x82, 0x21, 0x95, 0xc0, 0x5b,
    0xc3, 0xa3, 0xfd, 0xd3, 0xe8, 0x8a, 0x29, 0xfd, 0xe0, 0xa8, 0x7e, 0x74, 0x4e, 0xd3, 0x59, 0xeb,
    0xd3, 0x58, 0x87, 0xce, 0xfa, 0x2f, 0x2e, 0x3b, 0x44, 0x63, 0x76, 0x80, 0xbe, 0xfd, 0xfd, 0x5b,
    0x69, 0xf9, 0x2f, 0x75, 0x1f, 0xba, 0xf6, 0x82, 0x5f, 0x9a, 0xfb, 0xfa, 0x56, 0x84, 0x34, 0xb7,
    0x3d, 0x25, 0x41, 0x55, 0xa8, 0x27, 0x04, 0x31, 0x25, 0xd9, 0x93, 0xc1, 0x34, 0x4b, 0x92, 0xa2,
    0x79, 0xb3, 0x83, 0xad, 0xa1, 0x39, 0x43, 0x08, 0x89, 0x2e, 0xba, 0xce, 0x19, 0x0d, 0x28, 0x50,
    0x56, 0xfc, 0x82, 0x3c, 0x93, 0x38, 0x93, 0xac, 0xd4, 0x16, 0xa7, 0xda, 0x75, 0x2c, 0x2a, 0x99,
    0xf5, 0xcd, 0xf8, 0x3f, 0x85, 0xbb, 0x26, 0x33, 0xc3, 0x83, 0xf4, 0x9c, 0x06, 0xab, 0xca, 0x18,
    0x3d, 0x3e, 0xda, 0x9c, 0x7c, 0xfc, 0xf6, 0xee, 0xde, 0xec, 0xcd, 0xf0, 0x74, 0x2f, 0xf9, 0xa9,
    0xb1, 0x57, 0xdb, 0x91, 0x72, 0x26, 0x99, 0xa1, 0xdc, 0x04, 0x32, 0xa3, 0xea, 0x8c, 0x49, 0x92,
    0x4c, 0x94, 0x75, 0x92, 0x74, 0x2c, 0x5d, 0x97, 0xc6, 0xbd, 0x1f, 0x9b, 0xdd, 0x00, 0x06, 0x87,
    0x35, 0xc1, 0x93, 0x85, 0x72, 0x7d, 0x8a, 0xa1, 0x53, 0x90, 0x24, 0xb0, 0xfa, 0x43, 0x9a, 0x0f,
    0x9e, 0x7b, 0xf9, 0x98
};
#endif

PyTypeObject *init_QWebEngineFrame(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineFrame_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWebEngineFrame_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineFrame",
        "QWebEngineFrame",
        &Sbk_QWebEngineFrame_spec,
        &Shiboken::callCppDestructor< ::QWebEngineFrame >,
        Sbk_QWebEngineFrame_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QWebEngineFrame_TypeF(); // references _Sbk_QWebEngineFrame_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineFrame_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineFrame_SignatureBytes, QWebEngineFrame_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineFrame_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFrame_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineFrame_PythonToCpp_QWebEngineFrame_PTR,
        is_QWebEngineFrame_PythonToCpp_QWebEngineFrame_PTR_Convertible,
        QWebEngineFrame_PTR_CppToPython_QWebEngineFrame,
        QWebEngineFrame_COPY_CppToPython_QWebEngineFrame);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineFrame");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineFrame*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineFrame&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineFrame).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QWebEngineFrame_PythonToCpp_QWebEngineFrame_COPY,
        is_QWebEngineFrame_PythonToCpp_QWebEngineFrame_COPY_Convertible);


    return pyType;
}
