// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebview_python.h"

// main header
#include "qtwebview_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int Sbk_QtWebView_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNamespace("QtWebView");
    return -1;
}

static PyObject *Sbk_QtWebViewFunc_initialize(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // initialize()
        ::QtWebView::initialize();
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QtWebView_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QtWebView_methods[] = {
    {"initialize", reinterpret_cast<PyCFunction>(Sbk_QtWebViewFunc_initialize), METH_NOARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QtWebView_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QtWebView_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QtWebView_Type = nullptr;
static PyTypeObject *Sbk_QtWebView_TypeF(void)
{
    return _Sbk_QtWebView_Type;
}

static PyType_Slot Sbk_QtWebView_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(Sbk_object_dealloc /* PYSIDE-832: Prevent replacement of "0" with subtype_dealloc. */)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QtWebView_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QtWebView_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QtWebView_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QtWebView_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QtWebView_spec = {
    "2:PySide6.QtWebView.QtWebView",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QtWebView_slots
};

} //extern "C"

// Type conversion functions.

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QtWebViewQtWebView_SignatureStrings[] = {
    "PySide6.QtWebView.QtWebView.initialize()",
    nullptr}; // Sentinel
#else
static constexpr size_t QtWebViewQtWebView_SignatureByteSize = 40;
static constexpr uint8_t QtWebViewQtWebView_SignatureBytes[40] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x4f, 0x4d, 0x0a,
    0xcb, 0x4c, 0x2d, 0x47, 0x62, 0x65, 0xe6, 0x65, 0x96, 0x64, 0x26, 0xe6, 0x64, 0x56, 0xa5, 0x6a,
    0x68, 0x72, 0x01, 0x00, 0x38, 0x3a, 0x0e, 0x98
};
#endif

PyTypeObject *init_QtWebViewQtWebView(PyObject *module)
{
    if (SbkPySide6_QtWebViewTypeStructs[SBK_QtWebViewQtWebView_IDX].type != nullptr)
        return SbkPySide6_QtWebViewTypeStructs[SBK_QtWebViewQtWebView_IDX].type;

    Shiboken::AutoDecRef Sbk_QtWebView_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QtWebView_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QtWebView",
        "QtWebView",
        &Sbk_QtWebView_spec,
        nullptr,
        Sbk_QtWebView_Type_bases.object(),
        0);
    auto *pyType = Sbk_QtWebView_TypeF(); // references _Sbk_QtWebView_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QtWebViewQtWebView_SignatureStrings);
#else
    InitSignatureBytes(pyType, QtWebViewQtWebView_SignatureBytes, QtWebViewQtWebView_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QtWebView_PropertyStrings);
    SbkPySide6_QtWebViewTypeStructs[SBK_QtWebViewQtWebView_IDX].type = pyType;



    return pyType;
}
